# 3.7.1.0版本

1. 适配vnpy框架4.0版本
2. 增加行情数据中的合约交易和收盘状态

# 3.7.0.0版本

1. 升级到6.7.0版本的API

# 3.5.5.2版本

1. 修复由于流控导致的委托失败时，返回【提交中】状态委托的问题

# 3.5.5.2版本

1. 修复打包文件缺少lib的问题
2. 使用zoneinfo替换pytz库
3. 调整安装脚本setup.cfg，添加Python版本限制

# 3.5.5.1版本

1. 调整安装脚本setup.py，支持Windows下安装时根据Python版本进行编译
2. 调整接口初始化时，接口名称的赋值方式
